Changelog
=========

0.1.4 (2023-07-07)
------------------

- fixed password support


0.1.3 (2023-07-07)
------------------

- added support for supplying a password for connecting to the Redis server (`--password` or `--password_env`)


0.1.2 (2021-10-01)
------------------

- `listen.py` now supports output in a directory


0.1.1 (2021-09-22)
------------------

- `broadcast.py` now supports reading binary files and just using simple strings


0.1.0 (2021-09-14)
------------------

- initial release

